==> incidenceeditor-16.11.90.tar.xz: incidenceeditor-16.11.90/src/freebusyurldialog.h <==
/*
  Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

  As a special exception, permission is given to link this program
  with any edition of Qt, and distribute the resulting executable,
  without including the source code for Qt in the source distribution.
*/
#ifndef INCIDENCEEDITOR_FREEBUSYURLDIALOG_H
#define INCIDENCEEDITOR_FREEBUSYURLDIALOG_H

#include "attendeedata.h"

#include <QDialog>

class KLineEdit;

namespace IncidenceEditorNG
{

class FreeBusyUrlWidget;

class FreeBusyUrlDialog : public QDialog
{
    Q_OBJECT
public:
    explicit FreeBusyUrlDialog(const AttendeeData::Ptr &, QWidget *parent = Q_NULLPTR);

public Q_SLOTS:
    void slotOk();

private:
    FreeBusyUrlWidget *mWidget;
};

class FreeBusyUrlWidget : public QWidget
{
    Q_OBJECT
public:
    explicit FreeBusyUrlWidget(const AttendeeData::Ptr &, QWidget *parent = Q_NULLPTR);
    ~FreeBusyUrlWidget();

    void loadConfig();
    void saveConfig();

private:
    KLineEdit *mUrlEdit;
    AttendeeData::Ptr mAttendee;
};

}

#endif

==> incidenceeditor-17.04.1.tar.xz: incidenceeditor-17.04.1/src/freebusyurldialog.h <==
/*
  Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

  As a special exception, permission is given to link this program
  with any edition of Qt, and distribute the resulting executable,
  without including the source code for Qt in the source distribution.
*/
#ifndef INCIDENCEEDITOR_FREEBUSYURLDIALOG_H
#define INCIDENCEEDITOR_FREEBUSYURLDIALOG_H

#include "attendeedata.h"

#include <QDialog>

class KLineEdit;

namespace IncidenceEditorNG
{

class FreeBusyUrlWidget;

class FreeBusyUrlDialog : public QDialog
{
    Q_OBJECT
public:
    explicit FreeBusyUrlDialog(const AttendeeData::Ptr &, QWidget *parent = nullptr);

public Q_SLOTS:
    void slotOk();

private:
    FreeBusyUrlWidget *mWidget;
};

class FreeBusyUrlWidget : public QWidget
{
    Q_OBJECT
public:
    explicit FreeBusyUrlWidget(const AttendeeData::Ptr &, QWidget *parent = nullptr);
    ~FreeBusyUrlWidget();

    void loadConfig();
    void saveConfig();

private:
    KLineEdit *mUrlEdit;
    AttendeeData::Ptr mAttendee;
};

}

#endif
